/**
 * 演示程序当前的 “注册/登录” 等操作，是基于 “本地存储” 完成的
 * 当您要参考这个演示程序进行相关 app 的开发时，
 * 请注意将相关方法调整成 “基于服务端Service” 的实现。
 **/
importFile("/scripts/js/ffs/ffs.common.md5.js");
importFile("/scripts/js/ffs/ffs.localStorage.js");

(function($, owner) {
	/**
	 * 用户登录
	 **/
	owner.login = function(btn, loginInfo, callback) {
		callback = callback || $.noop;
		loginInfo = loginInfo || {};
		loginInfo.username = loginInfo.username || '';
		loginInfo.password = loginInfo.password || '';
		if(loginInfo.username.length < 6) {
			return callback('账号最短为 6 个字符');
		}
		if(loginInfo.password.length < 6) {
			return callback('密码最短为 6 个字符');
		}

		// 密码加密
		loginInfo.password = MD5(loginInfo.password);

		var url = nowApiUri() + '/auth/loginAction.json';
		var onloadFunc = function(result) {
			if(result.isSuccess == true) {
				ffsLocalStorage.setMemberInfo(result.data);
				ffsLocalStorage.setIsAutoLogin(true);

				return callback();
			}
			return callback("验证失败：" + result.message);
		}

		httpRequestPost(url, loginInfo, true, onloadFunc, btn);
	};

	owner.createState = function(name, callback) {
		var state = owner.getState();
		state.account = name;
		state.token = "token123456789";
		owner.setState(state);
		return callback();
	};

	/**
	 * 新用户注册
	 **/
	owner.reg = function(btn, regInfo, callback) {
		callback = callback || $.noop;
		regInfo = regInfo || {};
		regInfo.username = regInfo.username || '';
		regInfo.nickname = regInfo.nickname || '';
		regInfo.password = regInfo.password || '';

		if(checkEmail(regInfo.username)) {
			regInfo.email = regInfo.username;
		} else {
			return callback('账号名称不合法，请输入正确的邮箱地址！');
		}
		if(regInfo.nickname.length < 2) {
			return callback('昵称最短需要 2 个字符');
		}
		if(regInfo.nickname.length > 16) {
			return callback('昵称不能超过16个字符');
		}
		if(regInfo.password.length < 6) {
			return callback('密码最短需要 6 个字符');
		}
		if(regInfo.password.length > 32) {
			return callback('密码不能超过32个字符');
		}

		// 密码加密
		regInfo.password = MD5(regInfo.password)

		var url = nowApiUri() + '/auth/registerAction.json';
		var onloadFunc = function(result) {
			if(result.isSuccess == true) {
				return callback(); //
			}
			return callback("验证失败：" + result.message);
		};
		httpRequestPost(url, regInfo, true, onloadFunc, btn);
	};

	/**
	 * 获取当前状态
	 **/
	owner.getState = function() {
		var stateText = localStorage.getItem('$state') || "{}";
		return JSON.parse(stateText);
	};

	/**
	 * 设置当前状态
	 **/
	owner.setState = function(state) {
		state = state || {};
		localStorage.setItem('$state', JSON.stringify(state));
		//var settings = owner.getSettings();
		//settings.gestures = '';
		//owner.setSettings(settings);
	};

	var checkEmail = function(value) {
		value = value || '';
		return(value.length > 6 && value.indexOf('@') > -1);
	};

	var checkPhone = function(value) {
		value = value || '';
		return(value.length == 11 && !isNaN(value) == true);
	};

	/**
	 * 找回密码
	 **/
	owner.forgetPassword = function(email, callback) {
		callback = callback || $.noop;
		if(!checkEmail(email)) {
			return callback('邮箱地址不合法');
		}
		return callback(null, '新的随机密码已经发送到您的邮箱，请查收邮件。');
	};

	/**
	 * 获取应用本地配置
	 **/
	owner.setSettings = function(settings) {
		settings = settings || {};
		localStorage.setItem('$settings', JSON.stringify(settings));
	}

	/**
	 * 设置应用本地配置
	 **/
	owner.getSettings = function() {
		var settingsText = localStorage.getItem('$settings') || "{}";
		return JSON.parse(settingsText);
	}
}(mui, window.app = {}));

function UserInfo() {};

//清除登录信息
UserInfo.logout = function() {
	plus.storage.removeItem('memberId');
	plus.storage.removeItem('memberSn');
	plus.storage.removeItem('username');
	plus.storage.removeItem('password');
	plus.storage.removeItem('token');
	plus.storage.removeItem('nickname');
}

//检查是否包含自动登录的信息
UserInfo.autoLogin = function() {
	var username = UserInfo.username();
	var pwd = UserInfo.password();
	if(!username || !pwd) {
		return false;
	}
	return true;
}

//检查是否已登录
UserInfo.hasLogin = function() {
	var username = UserInfo.username();
	var pwd = UserInfo.password();
	var token = UserInfo.token();
	if(!username || !pwd || !token) {
		return false;
	}
	return true;
};

UserInfo.memberId = function() {
	if(arguments.length == 0) {
		return plus.storage.getItem('memberId');
	}
	if(arguments[0] === '') {
		plus.storage.removeItem('memberId');
		return;
	}
	plus.storage.setItem('memberId', arguments[0]);
};

UserInfo.memberSn = function() {
	if(arguments.length == 0) {
		return plus.storage.getItem('memberSn');
	}
	if(arguments[0] === '') {
		plus.storage.removeItem('memberSn');
		return;
	}
	plus.storage.setItem('memberSn', arguments[0]);
};

UserInfo.username = function() {
	if(arguments.length == 0) {
		return plus.storage.getItem('username');
	}
	if(arguments[0] === '') {
		plus.storage.removeItem('username');
		return;
	}
	plus.storage.setItem('username', arguments[0]);
};

UserInfo.nickname = function() {
	if(arguments.length == 0) {
		return plus.storage.getItem('nickname');
	}
	if(arguments[0] === '') {
		plus.storage.removeItem('nickname');
		return;
	}
	plus.storage.setItem('nickname', arguments[0]);
};

UserInfo.token = function() {
	if(arguments.length == 0) {
		return plus.storage.getItem('token');
	}
	if(arguments[0] === '') {
		plus.storage.removeItem('token');
		return;
	}
	plus.storage.setItem('token', arguments[0]);
};